@@ -93,6 +93,7 @@ def graph_figure(
         show_ports: bool = True,
         store_color: Any = 'tab:blue',
         process_color: Any = 'tab:orange',
+        color_edges: bool = True,
         fill_color: Any = 'w',
         node_size: float = 8000,
         font_size: int = 14,
@@ -108,6 +109,7 @@ def graph_figure(
     :param show_ports: whether to show the Port labels
     :param store_color: color for the Store nodes; any matplotlib color value
     :param process_color: color for the Process nodes; any matplotlib color value
+    :param color_edges: color each edge between Store and Process a different color
     :param fill_color: fill color for the Store and Process nodes; any
         matplotlib color value
     :param node_size: size to draw the Store and Process nodes
@@ -162,7 +164,10 @@ def graph_figure(
                            node_shape=cast(str, STORAGE_PATH)
                            )
     # edges
-    colors = list(range(1, len(edges) + 1))
+    if color_edges:
+        colors = list(range(1, len(edges) + 1))
+    else:
+        colors = 'k'
     nx.draw_networkx_edges(graph, pos,
                            edge_color=colors,
                            width=1.5)
