@@ -5,21 +5,17 @@ Burst Process
 """
 
 import os
-import uuid
-import logging as log
 
 from vivarium.core.experiment import pp
 from vivarium.core.process import (
     Deriver,
     Factory,
 )
-from vivarium.library.units import units
 from vivarium.core.composition import (
     compose_experiment,
     GENERATORS_KEY,
     PROCESS_OUT_DIR,
 )
-from vivarium.plots.simulation_output import plot_simulation_output
 from vivarium.processes.exchange_a import ExchangeA
 from vivarium.processes.timeline import TimelineProcess
 
@@ -118,10 +114,10 @@ def test_burst():
     agent_2_id = '2'
 
     # initial state
-    initial_A = 10
+    initial_a = 10
     initial_state = {
         'concentrations': {
-            'A': initial_A
+            'A': initial_a
         },
         'agents': {
             agent_1_id: {
@@ -199,11 +195,12 @@ def test_burst():
     experiment.end()  # end required for parallel processes
 
     # asserts total A is the same at the beginning and the end
-    assert output[0.0]['concentrations']['A'] == initial_A
-    assert output[5.0]['concentrations']['A'] + output[5.0]['agents'][agent_1_id]['concentrations']['A'] == initial_A
+    assert output[0.0]['concentrations']['A'] == initial_a
+    assert output[5.0]['concentrations']['A'] + output[5.0]['agents'][agent_1_id]['concentrations']['A'] == initial_a
 
     return output
 
+
 def run_burst():
     out_dir = os.path.join(PROCESS_OUT_DIR, NAME)
     if not os.path.exists(out_dir):
@@ -212,6 +209,5 @@ def run_burst():
     pp(output)
 
 
-
 if __name__ == '__main__':
     run_burst()
